title: Test markdown File
category: test

Test Markdown File Header
=========================

Used for pelican test
---------------------

This is another markdown test file.  Uses the markdown extension.
